@@ -38,14 +38,14 @@
 #' @source HYDAT
 #' @export
 
-
-
-hy_sed_daily_suscon <- function(station_number = NULL,
-                                hydat_path = NULL,
-                                prov_terr_state_loc = NULL,
-                                start_date = NULL,
-                                end_date = NULL,
-                                symbol_output = "code") {
+hy_sed_daily_suscon <- function(
+  station_number = NULL,
+  hydat_path = NULL,
+  prov_terr_state_loc = NULL,
+  start_date = NULL,
+  end_date = NULL,
+  symbol_output = "code"
+) {
   ## Determine which dates should be queried
   dates_null <- date_check(start_date, end_date)
 
@@ -67,16 +67,31 @@ hy_sed_daily_suscon <- function(station_number = NULL,
 
   ## Data manipulations
   sed_dly_suscon <- dplyr::tbl(hydat_con, "SED_DLY_SUSCON")
-  sed_dly_suscon <- dplyr::filter(sed_dly_suscon, !!sym_STATION_NUMBER %in% stns)
+  sed_dly_suscon <- dplyr::filter(
+    sed_dly_suscon,
+    !!sym_STATION_NUMBER %in% stns
+  )
 
   ## Do the initial subset to take advantage of dbplyr only issuing sql query when it has too
 
   ## by year
-  if (!dates_null[["start_is_null"]]) sed_dly_suscon <- dplyr::filter(sed_dly_suscon, !!sym_YEAR >= lubridate::year(start_date))
-  if (!dates_null[["end_is_null"]]) sed_dly_suscon <- dplyr::filter(sed_dly_suscon, !!sym_YEAR <= lubridate::year(end_date))
+  if (!dates_null[["start_is_null"]])
+    sed_dly_suscon <- dplyr::filter(
+      sed_dly_suscon,
+      !!sym_YEAR >= lubridate::year(start_date)
+    )
+  if (!dates_null[["end_is_null"]])
+    sed_dly_suscon <- dplyr::filter(
+      sed_dly_suscon,
+      !!sym_YEAR <= lubridate::year(end_date)
+    )
 
   sed_dly_suscon <- dplyr::select(
-    sed_dly_suscon, STATION_NUMBER, YEAR, MONTH, NO_DAYS,
+    sed_dly_suscon,
+    STATION_NUMBER,
+    YEAR,
+    MONTH,
+    NO_DAYS,
     dplyr::contains("SUSCON")
   )
   sed_dly_suscon <- dplyr::collect(sed_dly_suscon)
@@ -85,53 +100,93 @@ hy_sed_daily_suscon <- function(station_number = NULL,
     stop("No suspended sediment data for this station in HYDAT")
   }
 
-  sed_dly_suscon <- tidyr::gather(sed_dly_suscon, !!sym_variable, !!sym_temp, -(STATION_NUMBER:NO_DAYS))
-  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, DAY = as.numeric(gsub("SUSCON|SUSCON_SYMBOL", "", variable)))
-  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, variable = gsub("[0-9]+", "", variable))
+  sed_dly_suscon <- tidyr::gather(
+    sed_dly_suscon,
+    !!sym_variable,
+    !!sym_temp,
+    -(STATION_NUMBER:NO_DAYS)
+  )
+  sed_dly_suscon <- dplyr::mutate(
+    sed_dly_suscon,
+    DAY = as.numeric(gsub("SUSCON|SUSCON_SYMBOL", "", variable))
+  )
+  sed_dly_suscon <- dplyr::mutate(
+    sed_dly_suscon,
+    variable = gsub("[0-9]+", "", variable)
+  )
   sed_dly_suscon <- tidyr::spread(sed_dly_suscon, !!sym_variable, !!sym_temp)
   sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, SUSCON = as.numeric(SUSCON))
   ## No days that exceed actual number of days in the month
   sed_dly_suscon <- dplyr::filter(sed_dly_suscon, DAY <= NO_DAYS)
 
   ## convert into R date.
-  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, Date = lubridate::ymd(
-    paste0(YEAR, "-", MONTH, "-", DAY)
-  ))
+  sed_dly_suscon <- dplyr::mutate(
+    sed_dly_suscon,
+    Date = lubridate::ymd(
+      paste0(YEAR, "-", MONTH, "-", DAY)
+    )
+  )
 
   ## Then when a date column exist fine tune the subset
-  if (!dates_null[["start_is_null"]]) sed_dly_suscon <- dplyr::filter(sed_dly_suscon, !!sym_Date >= start_date)
-  if (!dates_null[["end_is_null"]]) sed_dly_suscon <- dplyr::filter(sed_dly_suscon, !!sym_Date <= end_date)
+  if (!dates_null[["start_is_null"]])
+    sed_dly_suscon <- dplyr::filter(sed_dly_suscon, !!sym_Date >= start_date)
+  if (!dates_null[["end_is_null"]])
+    sed_dly_suscon <- dplyr::filter(sed_dly_suscon, !!sym_Date <= end_date)
 
-
-  sed_dly_suscon <- dplyr::left_join(sed_dly_suscon, tidyhydat::hy_data_symbols, by = c("SUSCON_SYMBOL" = "SYMBOL_ID"))
+  sed_dly_suscon <- dplyr::left_join(
+    sed_dly_suscon,
+    tidyhydat::hy_data_symbols,
+    by = c("SUSCON_SYMBOL" = "SYMBOL_ID")
+  )
   sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, Parameter = "Suscon")
 
   ## Control for symbol ouput
   if (symbol_output == "code") {
     sed_dly_suscon <- dplyr::select(
-      sed_dly_suscon, STATION_NUMBER, Date, Parameter,
-      SUSCON, SUSCON_SYMBOL
+      sed_dly_suscon,
+      STATION_NUMBER,
+      Date,
+      Parameter,
+      SUSCON,
+      SUSCON_SYMBOL
     )
   }
 
   if (symbol_output == "english") {
     sed_dly_suscon <- dplyr::select(
-      sed_dly_suscon, STATION_NUMBER, Date, Parameter,
-      SUSCON, SYMBOL_EN
+      sed_dly_suscon,
+      STATION_NUMBER,
+      Date,
+      Parameter,
+      SUSCON,
+      SYMBOL_EN
     )
   }
 
   if (symbol_output == "french") {
     sed_dly_suscon <- dplyr::select(
-      sed_dly_suscon, STATION_NUMBER, Date, Parameter,
-      SUSCON, SYMBOL_FR
+      sed_dly_suscon,
+      STATION_NUMBER,
+      Date,
+      Parameter,
+      SUSCON,
+      SYMBOL_FR
     )
   }
 
   sed_dly_suscon <- dplyr::arrange(sed_dly_suscon, Date)
 
-  colnames(sed_dly_suscon) <- c("STATION_NUMBER", "Date", "Parameter", "Value", "Symbol")
+  colnames(sed_dly_suscon) <- c(
+    "STATION_NUMBER",
+    "Date",
+    "Parameter",
+    "Value",
+    "Symbol"
+  )
 
-  attr(sed_dly_suscon, "missed_stns") <- setdiff(unique(stns), unique(sed_dly_suscon$STATION_NUMBER))
+  attr(sed_dly_suscon, "missed_stns") <- setdiff(
+    unique(stns),
+    unique(sed_dly_suscon$STATION_NUMBER)
+  )
   as.hy(sed_dly_suscon)
 }
