@@ -44,13 +44,13 @@
 #' @source HYDAT
 #' @export
 
-
-
-hy_sed_monthly_loads <- function(station_number = NULL,
-                                 hydat_path = NULL,
-                                 prov_terr_state_loc = NULL,
-                                 start_date = NULL,
-                                 end_date = NULL) {
+hy_sed_monthly_loads <- function(
+  station_number = NULL,
+  hydat_path = NULL,
+  prov_terr_state_loc = NULL,
+  start_date = NULL,
+  end_date = NULL
+) {
   ## Determine which dates should be queried
   dates_null <- date_check(start_date, end_date)
 
@@ -60,7 +60,6 @@ hy_sed_monthly_loads <- function(station_number = NULL,
     on.exit(hy_src_disconnect(hydat_con), add = TRUE)
   }
 
-
   ## Determine which stations we are querying
   stns <- station_choice(hydat_con, station_number, prov_terr_state_loc)
 
@@ -73,13 +72,24 @@ hy_sed_monthly_loads <- function(station_number = NULL,
 
   ## Data manipulations to make it "tidy"
   sed_monthly_loads <- dplyr::tbl(hydat_con, "SED_DLY_LOADS")
-  sed_monthly_loads <- dplyr::filter(sed_monthly_loads, !!sym_STATION_NUMBER %in% stns)
+  sed_monthly_loads <- dplyr::filter(
+    sed_monthly_loads,
+    !!sym_STATION_NUMBER %in% stns
+  )
 
   ## Do the initial subset to take advantage of dbplyr only issuing sql query when it has too
 
   ## by year
-  if (!dates_null[["start_is_null"]]) sed_monthly_loads <- dplyr::filter(sed_monthly_loads, !!sym_YEAR >= lubridate::year(start_date))
-  if (!dates_null[["end_is_null"]]) sed_monthly_loads <- dplyr::filter(sed_monthly_loads, !!sym_YEAR <= lubridate::year(end_date))
+  if (!dates_null[["start_is_null"]])
+    sed_monthly_loads <- dplyr::filter(
+      sed_monthly_loads,
+      !!sym_YEAR >= lubridate::year(start_date)
+    )
+  if (!dates_null[["end_is_null"]])
+    sed_monthly_loads <- dplyr::filter(
+      sed_monthly_loads,
+      !!sym_YEAR <= lubridate::year(end_date)
+    )
 
   sed_monthly_loads <- dplyr::select(sed_monthly_loads, STATION_NUMBER:MAX)
   sed_monthly_loads <- dplyr::collect(sed_monthly_loads)
@@ -90,31 +100,71 @@ hy_sed_monthly_loads <- function(station_number = NULL,
 
   ## Need to rename columns for gather
   colnames(sed_monthly_loads) <- c(
-    "STATION_NUMBER", "Year", "Month", "Full_Month", "No_days", "MEAN_Value",
-    "TOTAL_Value", "MIN_DAY", "MIN_Value", "MAX_DAY", "MAX_Value"
+    "STATION_NUMBER",
+    "Year",
+    "Month",
+    "Full_Month",
+    "No_days",
+    "MEAN_Value",
+    "TOTAL_Value",
+    "MIN_DAY",
+    "MIN_Value",
+    "MAX_DAY",
+    "MAX_Value"
   )
 
-
-
-  sed_monthly_loads <- tidyr::gather(sed_monthly_loads, !!sym_variable, !!sym_temp, -(STATION_NUMBER:No_days))
-  sed_monthly_loads <- tidyr::separate(sed_monthly_loads, !!sym_variable, into = c("Sum_stat", "temp2"), sep = "_")
+  sed_monthly_loads <- tidyr::gather(
+    sed_monthly_loads,
+    !!sym_variable,
+    !!sym_temp,
+    -(STATION_NUMBER:No_days)
+  )
+  sed_monthly_loads <- tidyr::separate(
+    sed_monthly_loads,
+    !!sym_variable,
+    into = c("Sum_stat", "temp2"),
+    sep = "_"
+  )
 
   sed_monthly_loads <- tidyr::spread(sed_monthly_loads, !!sym_temp2, !!sym_temp)
 
   ## convert into R date for date of occurence.
-  sed_monthly_loads <- dplyr::mutate(sed_monthly_loads, Date_occurred = paste0(Year, "-", Month, "-", DAY))
+  sed_monthly_loads <- dplyr::mutate(
+    sed_monthly_loads,
+    Date_occurred = paste0(Year, "-", Month, "-", DAY)
+  )
 
   ## Check if DAY is NA and if so give it an NA value so the date parse correctly.
-  sed_monthly_loads <- dplyr::mutate(sed_monthly_loads, Date_occurred = ifelse(is.na(DAY), NA, Date_occurred))
-  sed_monthly_loads <- dplyr::mutate(sed_monthly_loads, Date_occurred = lubridate::ymd(Date_occurred, quiet = TRUE))
+  sed_monthly_loads <- dplyr::mutate(
+    sed_monthly_loads,
+    Date_occurred = ifelse(is.na(DAY), NA, Date_occurred)
+  )
+  sed_monthly_loads <- dplyr::mutate(
+    sed_monthly_loads,
+    Date_occurred = lubridate::ymd(Date_occurred, quiet = TRUE)
+  )
 
   ## Then when a date column exist fine tune the subset
-  if (!dates_null[["start_is_null"]]) sed_monthly_loads <- dplyr::filter(sed_monthly_loads, Date_occurred >= start_date)
-  if (!dates_null[["end_is_null"]]) sed_monthly_loads <- dplyr::filter(sed_monthly_loads, Date_occurred <= end_date)
+  if (!dates_null[["start_is_null"]])
+    sed_monthly_loads <- dplyr::filter(
+      sed_monthly_loads,
+      Date_occurred >= start_date
+    )
+  if (!dates_null[["end_is_null"]])
+    sed_monthly_loads <- dplyr::filter(
+      sed_monthly_loads,
+      Date_occurred <= end_date
+    )
 
   sed_monthly_loads <- dplyr::select(sed_monthly_loads, -DAY)
-  sed_monthly_loads <- dplyr::mutate(sed_monthly_loads, Full_Month = Full_Month == 1)
+  sed_monthly_loads <- dplyr::mutate(
+    sed_monthly_loads,
+    Full_Month = Full_Month == 1
+  )
 
-  attr(sed_monthly_loads, "missed_stns") <- setdiff(unique(stns), unique(sed_monthly_loads$STATION_NUMBER))
+  attr(sed_monthly_loads, "missed_stns") <- setdiff(
+    unique(stns),
+    unique(sed_monthly_loads$STATION_NUMBER)
+  )
   as.hy(sed_monthly_loads)
 }
